@@ -7,6 +7,7 @@ import matplotlib.pyplot as plt
 from scipy.optimize import curve_fit
 from . import extra_funcs as ef
 from copy import deepcopy
+import inspect
 
 exval, exUnis = {}, {}
 
@@ -388,7 +389,10 @@ class table:
             dt.newCol(xn, xn)
         if yn not in self.data.columns:
             dt.newCol(yn, yn)
-        ax.errorbar(*dt[[xn, yn, ef.delt(yn), ef.delt(xn)]].T, ".", **kwargs)
+        if sum(dt[ef.delt(xn)]) == sum(dt[ef.delt(yn)]) == 0:
+            ax.plot(*dt[[xn, yn]].T, ".", **kwargs)
+        else:
+            ax.errorbar(*dt[[xn, yn, ef.delt(yn), ef.delt(xn)]].T, ".", **kwargs)
         ax.set_xlabel(ef.ax_name(dt, xn))
         ax.set_ylabel(ef.ax_name(dt, yn))
         # plt.legend()
@@ -409,14 +413,19 @@ class table:
 
         (show) If True, shows the data and the fit
 
+        (p0) Initial parameters
+
         (maxfev) Maximum number of itteration to find optimals parameters
         """
         if fig_ax == None:
             fig_ax = plt.figure(), plt.gca()
         fig, ax = fig_ax
         popt, pcov = curve_fit(func, *self[[xn, yn]].T, p0=p0, maxfev=maxfev)
-        results = np.array([np.array([popt, np.sqrt(pcov.diagonal())]).T.flatten()])
-        dt = table('', data=results, AutoInsert=False)
+        res = np.array([np.array([popt, np.sqrt(pcov.diagonal())]).T.flatten()])
+        dt = table('', data=res, AutoInsert=False)
+        noms = list(inspect.signature(func).parameters.keys())
+        noms = list(map(lambda x: sp.latex(sp.sympify(ef.preSymp(x))), noms))
+        dt.renameCols(noms[1:])
         if show:
             x = np.linspace(*ef.extrem(self[xn]), 1000)
             self.plot(xn, yn, label="Données", fig_ax=fig_ax, **kwargs)
